@@ -41,10 +41,4 @@ class DescribeInstanceInfoRequest(RpcRequest):
 		return self.get_query_params().get('InstanceId')
 
 	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_InstanceSource(self):
-		return self.get_query_params().get('InstanceSource')
-
-	def set_InstanceSource(self,InstanceSource):
-		self.add_query_param('InstanceSource',InstanceSource)
\ No newline at end of file
+		self.add_query_param('InstanceId',InstanceId)
\ No newline at end of file
